package com.example.pda.ui

import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.itemsIndexed
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.SnackbarHost
import androidx.compose.material3.SnackbarHostState

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material.icons.filled.Home

import androidx.compose.material3.Scaffold
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
// 添加缺失的导入
import androidx.compose.runtime.getValue

import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel

import com.example.pda.R
import com.example.pda.function.ResultCount
import com.example.pda.function.ResultCounter
import com.example.pda.model.AppPrefs
import com.example.pda.ui.viewmodel.InventoryViewModel
import com.example.pda.model.InventoryItem
import com.example.pda.model.ContainerData
import kotlinx.coroutines.launch


@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun DetailsScreen(
    container: String,
    result: String,
    onBack: () -> Unit,
    onMainScreen: () -> Unit,
    onShelfScan: () -> Unit,

    ) {
    val snackbarHostState = remember { SnackbarHostState() }
    val scope = rememberCoroutineScope()
    val resultCounter = ResultCounter()
    val viewModel: InventoryViewModel = viewModel()
    val editableResults = remember {
        mutableStateListOf<ResultCount>().apply {
            addAll(resultCounter.getStatistics())
        }
    }
    // 使用 mutableStateList 保证Compose能感知变化
    val inventoryitems = remember { mutableStateListOf<InventoryItem>() }


    // 初始化数据
    LaunchedEffect(Unit) {
        result.split(",").forEach {
            resultCounter.addResult(it)
        }
        editableResults.clear()
        editableResults.addAll(
            resultCounter.getStatistics().map {
                ResultCount(
                    normalizedResult = it.normalizedResult,
                    occurrences = it.occurrences,
                    selectedSpec = ResultCount.Spec.OPTION_30KG
                )
            }
        )

        // 初始化库存列表
        inventoryitems.clear()
        inventoryitems.addAll(
            editableResults.map {
                InventoryItem(
                    it.normalizedResult,
                    it.occurrences,
                    specification = when (it.selectedSpec) {
                        is ResultCount.Spec.OPTION_30KG -> 30
                        is ResultCount.Spec.OPTION_25KG -> 25
                        is ResultCount.Spec.CUSTOM -> it.customValue.toIntOrNull() ?: 0
                    }
                )
            }
        )
    }

    // 更新文本输入时的数据同步
    fun updateInventoryItem(index: Int, newCount: Int) {
        val newItem = editableResults[index].copy(occurrences = newCount)
        editableResults[index] = newItem
        inventoryitems[index] = InventoryItem(
            newItem.normalizedResult,
            newCount,
            specification = when (newItem.selectedSpec) {
                is ResultCount.Spec.OPTION_30KG -> 30
                is ResultCount.Spec.OPTION_25KG -> 25
                is ResultCount.Spec.CUSTOM -> newItem.customValue.toIntOrNull() ?: 0
            }
        )
    }

    // 提交按钮的统一处理
    fun onSubmit() {
        val items = editableResults.map {
            InventoryItem(it.normalizedResult, it.occurrences,30)
        }
        inventoryitems.clear()
        inventoryitems.addAll(items)
    }
    val uiState = viewModel.uiState.collectAsState()

    LaunchedEffect(uiState.value) {
        when (val currentState = uiState.value) {
            is InventoryViewModel.UiState.Success -> {
                scope.launch {
                    snackbarHostState.showSnackbar(currentState.message)
                    viewModel.resetState()
                }
                resultCounter.clear()
                editableResults.clear()
            }
            is InventoryViewModel.UiState.Error -> {
                scope.launch {
                    snackbarHostState.showSnackbar("错误：${currentState.message}")
                    viewModel.resetState()
                }
            }
            else -> {}
        }
    }

    Scaffold(
        snackbarHost = { SnackbarHost(snackbarHostState) },
        topBar = {
            TopAppBar(
                title = { Text("扫描详情") },
                navigationIcon = {
                    IconButton(onClick = onBack) {
                        Icon(
                            imageVector = Icons.Default.ArrowBack,
                            contentDescription = "返回"
                        )
                    }
                }
            )
        },
        floatingActionButton = {
            Box(
                 modifier = Modifier.fillMaxWidth(),
                 contentAlignment = Alignment.Center

            ) {
            Row(
            modifier = Modifier
                .fillMaxWidth().padding(20.dp) ,
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.SpaceEvenly,

            ) {
                Spacer(Modifier.width(18.dp)) // 添加间距
                ExtendedFloatingActionButton(
                    modifier = Modifier.weight(1f),
                    onClick = onMainScreen,
                    icon = {
                        Icon(
                            imageVector = Icons.Default.Home,
                            contentDescription = "返回主页"
                        )
                       },
                    text = { Text("主页") }
                )

                Spacer(Modifier.width(8.dp)) // 添加间距

                ExtendedFloatingActionButton(
                    modifier = Modifier.weight(1f),
                    onClick = onShelfScan,
                    icon = {
                        Icon(
                            painter = painterResource(id = R.drawable.ic_scan),
                            contentDescription = "货架扫描"
                        )
                    },
                    text = { Text("托盘") }
                )
                Spacer(Modifier.width(8.dp)) // 添加间距

                ExtendedFloatingActionButton(
                    modifier = Modifier.weight(1f),

                    onClick ={
                        onSubmit()
                        val containerData = ContainerData(
                            container = container,
                            batches = inventoryitems.toList(),
                            username = AppPrefs.username
                        )
                        viewModel.submitData(containerData)
                             } ,
                    icon = {
                        Icon(
                            painter = painterResource(id = R.drawable.component),
                            contentDescription = "组盘入库"
                        )
                    },
                    text = { Text("组盘") }
                )
            }
            }
        }
    ) { innerPadding ->
        Column(
            modifier = Modifier
                .padding(innerPadding)
                .fillMaxSize()
                .padding(24.dp)
        ) {
            Text(
                text = "托盘编码：",
                style = MaterialTheme.typography.titleLarge
            )

            Spacer(modifier = Modifier.height(16.dp))

            Card(
                modifier = Modifier.fillMaxWidth()
            ) {
                Text(
                    text = container,
                    modifier = Modifier.padding(16.dp),
                    style = MaterialTheme.typography.bodyLarge,
                    overflow = TextOverflow.Ellipsis,
                    maxLines = 5
                )
            }
            // 观察状态变化

            // 新增统计列表
            Spacer(modifier = Modifier.height(24.dp))
            Row(
                modifier = Modifier.fillMaxWidth(),
                horizontalArrangement = Arrangement.SpaceBetween
            ) {
                Text("条码", style = MaterialTheme.typography.titleMedium)
                Text("数量", style = MaterialTheme.typography.titleMedium)
                Text("规格", style = MaterialTheme.typography.titleMedium)

            }

// 修改 LazyColumn 部分
            LazyColumn(
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(16.dp)
            ) {
                itemsIndexed(editableResults) { index, item ->

                    var expanded by remember { mutableStateOf(false) }
                    var customDialogVisible by remember { mutableStateOf(false) }
                    Row(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(vertical = 8.dp),
                        verticalAlignment = Alignment.CenterVertically,
                        horizontalArrangement = Arrangement.SpaceBetween
                    ) {
                        // 第一列：条码
                        Text(
                            text = item.normalizedResult,
                            modifier = Modifier.weight(1f),
                            overflow = TextOverflow.Ellipsis,
                            maxLines = 2
                        )

                        // 第二列：数量输入
                        OutlinedTextField(
                            value = item.occurrences.toString(),
                            onValueChange = { newValue ->
                                newValue.toIntOrNull()?.let { updateInventoryItem(index, it) }
                            },
                            modifier = Modifier
                                .width(70.dp)
                                .padding(horizontal = 4.dp),
                            keyboardOptions = KeyboardOptions.Default.copy(
                                keyboardType = KeyboardType.Number
                            )
                        )

                        // 第三列：规格选择
                        ExposedDropdownMenuBox(
                            expanded = expanded,
                            onExpandedChange = { expanded = expanded.not() },
                            modifier = Modifier
                                .weight(1f)
                                .padding(start = 8.dp)
                        ) {
                            OutlinedTextField(
                                value = when (item.selectedSpec) {
                                    is ResultCount.Spec.OPTION_30KG -> "30kg/组"
                                    is ResultCount.Spec.OPTION_25KG -> "25kg/组"
                                    is ResultCount.Spec.CUSTOM ->
                                        if (item.customValue.isEmpty()) "自定义kg/组"
                                        else "${item.customValue}kg/组"
                                },
                                onValueChange = {},
                                readOnly = true,
                                trailingIcon = {
                                    ExposedDropdownMenuDefaults.TrailingIcon(expanded = expanded)
                                },
                                modifier = Modifier
                                    .menuAnchor()
                                    .fillMaxWidth()
                            )

                            ExposedDropdownMenu(
                                expanded = expanded,
                                onDismissRequest = { expanded = false }
                            ) {
                                // 30kg选项
                                DropdownMenuItem(
                                    text = { Text("30kg/组") },
                                    onClick = {
                                        editableResults[index] = item.copy(
                                            selectedSpec = ResultCount.Spec.OPTION_30KG
                                        )
                                        expanded = false
                                    }
                                )

                                // 25kg选项
                                DropdownMenuItem(
                                    text = { Text("25kg/组") },
                                    onClick = {
                                        editableResults[index] = item.copy(
                                            selectedSpec = ResultCount.Spec.OPTION_25KG
                                        )
                                        expanded = false
                                    }
                                )

                                // 自定义选项
                                DropdownMenuItem(
                                    text = { Text("自定义kg/组") },
                                    onClick = {
                                        expanded = false
                                        customDialogVisible = true
                                    }
                                )
                            }
                        }
                    }

                    // 自定义输入对话框
                    if (customDialogVisible) {
                        AlertDialog(
                            onDismissRequest = { customDialogVisible = false },
                            title = { Text("输入自定义规格") },
                            text = {
                                OutlinedTextField(
                                    value = item.customValue,
                                    onValueChange = {
                                        editableResults[index] = item.copy(
                                            selectedSpec = ResultCount.Spec.CUSTOM,
                                            customValue = it
                                        )
                                    },
                                    keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
                                    label = { Text("输入公斤数") }
                                )
                            },
                            confirmButton = {
                                TextButton(
                                    onClick = { customDialogVisible = false }
                                ) {
                                    Text("确定")
                                }
                            }
                        )
                    }
                }
            }
        }
    }
}



