package com.example.pda.ui

import android.widget.Toast
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.clickable
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import com.example.pda.R
import com.example.pda.model.AppPrefs
import com.example.pda.network.RetrofitClient

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun SettingScreen(
    onPingScreen: () -> Unit
) {
    val context = LocalContext.current
    var inputUrl by remember { mutableStateOf("") }

    // 初始化时读取当前服务器地址
    LaunchedEffect(Unit) {
        inputUrl = AppPrefs.base_url
    }

    Scaffold(
        topBar = {
            TopAppBar(
                title = {
                    Row(verticalAlignment = Alignment.CenterVertically) {
                        Icon(
                            painter = painterResource(id = R.drawable.logo),
                            contentDescription = "PDA Logo",
                            modifier = Modifier.size(40.dp),
                            tint = MaterialTheme.colorScheme.surfaceTint
                        )
                        Spacer(Modifier.width(8.dp))
                        Text("信泰PDA扫描系统")
                    }
                },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = Color(0xFFBCD0C5),
                    titleContentColor = MaterialTheme.colorScheme.onPrimary,
                    actionIconContentColor = MaterialTheme.colorScheme.onPrimary
                )
            )
        },
    ) { innerPadding ->
        Column(
            modifier = Modifier
                .padding(innerPadding)
                .fillMaxSize()
                .padding(16.dp)
        ) {
            // 服务器地址设置
            Text(
                text = "服务器地址配置",
                style = MaterialTheme.typography.titleMedium,
                modifier = Modifier.padding(bottom = 8.dp)
            )

            TextField(
                value = inputUrl,
                onValueChange = { inputUrl = it },
                label = { Text("请输入服务器地址") },
                placeholder = { Text("示例: http://192.168.1.100:8080/") },
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(bottom = 16.dp)
            )

            Button(
                onClick = {
                    // 保存配置并重置网络客户端
                    AppPrefs.base_url = inputUrl
                    RetrofitClient.reset()
                    Toast.makeText(context, "服务器地址已更新", Toast.LENGTH_SHORT).show()
                },
                modifier = Modifier.fillMaxWidth()
            ) {
                Text("保存配置")
            }

            Spacer(Modifier.height(32.dp))

            // 原有功能区域
            Box(
                modifier = Modifier
                    .fillMaxWidth()
                    .clickable(enabled = true, onClick = { onPingScreen() }),
                contentAlignment = Alignment.Center
            ) {
                Text("PING监测", style = MaterialTheme.typography.titleMedium)
            }

            Spacer(Modifier.height(16.dp))

            Text(
                text = "当前登录用户: ${AppPrefs.username}",
                style = MaterialTheme.typography.bodyMedium
            )
        }
    }
}

